@@ -13,9 +13,3 @@ except ImportError:
           "(pip install padl-extensions[torchserve]) to use the connector")
     pass
 
-try:
-    from padl_ext.huggingface.convert import to_padl
-except ImportError:
-    print("Please install huggingface transformers dependencies "
-          "(pip install padl-extensions[huggingface]) to use connector")
-    pass
